@@ -1,4 +1,4 @@
-`crps.fitBMAgamma0` <-
+crps.fitBMAgamma0 <-
 function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...) 
 {
  powfun <- function(x,power) x^power
@@ -33,6 +33,8 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
  crpsSim <- rep(NA, nObs)
  names(crpsSim) <- ensembleObsLabels(ensembleData)
 
+ members <- ensembleMemberLabels(ensembleData)
+
  ensembleData <- ensembleForecasts(ensembleData)
 
  WEIGHTS <- fit$weights
@@ -57,38 +59,42 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
        PROB0 <- sapply(apply(rbind( 1, fTrans, f==0) * fit$prob0coefs,
                               2,sum), inverseLogit)
 
-       if (sum(!M) > 1) {  
-         W <- WEIGHTS + weps
-         W <- W[!M]/sum(W[!M])
-         SAMPLES <- sample( (1:nForecasts)[!M], size = nSamples, 
-                            replace = TRUE, prob = W)
-        }
-       else {
-         SAMPLES <- rep( (1:nForecasts)[!M], nSamples)
+       W <- WEIGHTS
+       if (any(M)) {
+         W <- W + weps
+         W <- W[!M] / sum(W[!M])
        }
 
-       tab <- table(SAMPLES)
-
-       tab <- table(unlist(apply( cbind(as.numeric(names(tab)), tab), 1,
-              function(nj,PROB0) {
-         sample(c(nj[1],0), size = nj[2], replace = TRUE,
-                prob = c(1-PROB0[nj[1]],PROB0[nj[1]]))}, 
-                PROB0 = PROB0[!M])))
-
-       if (length(tab) > 1) {
-          S <- apply( cbind(as.numeric(names(tab[-1])), tab[-1]), 1,
-              function(nj,SHAPE,RATE) 
-                  rgamma(nj[2], shape=SHAPE[nj[1]], rate=RATE[nj[1]]),
-                                        SHAPE = SHAPE[!M], RATE = RATE[!M])
-           
-# model is fit to the cube root of the forecast
-
-         S <- sapply(as.vector(unlist(S)), powinv, power = fit$power)
-
-         SAMPLES <- c(rep(0, tab[1]), S)
+       if (sum(!W) >  1) {
+         SAMPLES <- sample( (1:nForecasts)[!M], size = nSamples,
+                           replace = TRUE, prob = W) 
        }
-       else SAMPLES <- rep(0,tab[1])
-  
+       else SAMPLES <- rep( (1:nForecasts)[!M], nSamples)
+
+       tab <- rep(0, nForecasts)
+       names(tab) <- members
+       for (j in seq(along = tab)) tab[j] <- sum(SAMPLES == j)
+       
+       SAMPLES[] <- NA
+
+       jj <- 0
+       for (j in seq(along = tab)) {
+          nsamp <- tab[j]
+          if (nsamp == 0) next
+          z <- sample(c(0,1), size = nsamp, replace = TRUE, 
+                        prob = c(PROB0[j],1-PROB0[j]))
+          znonz <- z != 0
+          nnonz <- sum(znonz)
+          if (nnonz > 0) z[znonz] <- rgamma(nnonz,shape=SHAPE[j],rate=RATE[j])
+          SAMPLES[jj + 1:nsamp] <- z
+          jj <- jj + nsamp
+       }
+
+       nz <- SAMPLES != 0
+       if (any(nz)) SAMPLES[nz] <- sapply(SAMPLES[nz], powinv, power=fit$power)
+
+# crps2 approximates a term that is quadratic in the number of members 
+
        crps1  <- mean(abs(SAMPLES - obs[i])) 
        crps2 <-  mean(abs(diff(sample(SAMPLES))))
        crpsSim[i]  <- crps1 - crps2/2
